@@ -2,7 +2,6 @@ import logging
 from typing import Dict, Optional
 
 from aiohttp import ClientSession
-
 from pyuhoo.errors import ForbiddenError, UhooError, UnauthorizedError
 
 from .api import API
@@ -100,6 +99,7 @@ class Client(object):
             await self.login()
 
     async def get_latest_data(self) -> None:
+        await self.login()
         try:
             data_latest: dict = await self._api.data_latest_aqi()
         except UnauthorizedError:
@@ -119,6 +119,26 @@ class Client(object):
             await self.refresh_token()
             data_latest = await self._api.data_latest_aqi()
 
+    async def get_data(self) -> None:
+        try:
+            data_latest: dict = await self._api.data_latest_aqi()
+        except UnauthorizedError:
+            self._log.debug(
+                "\033[93m"
+                + "[get_latest_data] received 401 error, refreshing token and trying again"
+                + "\033[0m"
+            )
+        #     await self.refresh_token()
+        #     data_latest = await self._api.data_latest_aqi()
+        except ForbiddenError:
+            self._log.debug(
+                "\033[93m"
+                + "[get_latest_data] received 403 error, refreshing token and trying again"
+                + "\033[0m"
+            )
+        #     await self.refresh_token()
+        #     data_latest = await self._api.data_latest_aqi()
+
         # self._log.debug(f"[data_latest] returned\n{json_pp(data_latest)}")
 
         self.user_settings_temp = data_latest["userSettings"]["temp"]
